@@ -24,8 +24,8 @@ neighbours<-function(tri.obj)
                  nbnos=as.integer(nbnos),
                  na=as.integer(0),
                  nb=as.integer(0),
-                 nt=as.integer(0)
-                 )
+                 nt=as.integer(0),
+                 PACKAGE = "tripack")
   ret<-rep(NULL,tri.obj$n)
   for (i in 1:tri.obj$n)
     {
